@@ -40,7 +40,7 @@ class MainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
 public:
-    MainWindow(QWidget *parent = 0);
+    explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 public Q_SLOTS:
     void startGame(KDiamond::Mode mode);
